# we have several different ways of getting from source code
# to html documentation.

####
# constants for generating documentation
####
# whether to expand the "//:CLBEGIN" and so on as cxx or java
SRC2DOC_LANG          := java
SRC2DOC               := $(PERL) $(TOOLS_JSFILTER_DIR)/src2doc.pl -$(SRC2DOC_LANG)

# can be generated by `doxygen -g` or with doxywizard
# note that $(FOO) can be inserted into Doxyfile, and then set in env.
DOXYGEN_CONFIG        := $(TOOLS_JSFILTER_DIR)/Doxyfile_api.txt

# set to $(JS_SRC_DIR) if doing 1-stage processing
# DOXYGEN_STRIP_FROM_PATH := $(JS_SRC_DIR)
DOXYGEN_STRIP_FROM_PATH := $(BUILD_DIR)/doxysrc

# options for all calls to doxygen
DOXYGEN_ENV_BASE      := VERSION=$(BURSTVERSION) OUTPUT_DIRECTORY=$(APIDOC_DIR) STRIP_FROM_PATH=$(DOXYGEN_STRIP_FROM_PATH)
# when calling doxygen on sources with src2doc filter
DOXYGEN_ENV_SRC2DOC   := $(DOXYGEN_ENV_BASE) INPUT=$(JS_SRC_DIR) INPUT_FILTER="$(SRC2DOC)"
# when calling doxygen directly on js with no filter (for debugging) 
DOXYGEN_ENV_RAW       := $(DOXYGEN_ENV_BASE) INPUT=$(JS_SRC_DIR) INPUT_FILTER=
# when calling doxygen on generated sources in doxygen dir (if doing 2-stage processing)
DOXYGEN_ENV_BUILD     := $(DOXYGEN_ENV_BASE) INPUT=$(BUILD_DIR)/doxysrc INPUT_FILTER=

####
# target apidoc
####

# do it in two steps to get proper java file handling by doxygen
# apidoc: apidoc_src2doc
apidoc: src2doc apidoc_build

apidoc_clean:
	@rm -rf $(BUILD_DIR)/doxysrc $(APIDOC_DIR)

# run doxygen on js sources using src2doc.pl as filter (single step approach) 
apidoc_src2doc:
	@mkdir -p $(APIDOC_DIR)
	$(DOXYGEN_ENV_SRC2DOC) $(DOXYGEN) $(DOXYGEN_CONFIG)

# run doxygen directly on js sources with no filter
apidoc_raw:
	@mkdir -p $(APIDOC_DIR)
	$(DOXYGEN_ENV_RAW) $(DOXYGEN) $(DOXYGEN_CONFIG)

# file suffix to use for generated files 
DOC_SUFFIX := .java

# run src2doc.pl as filter (1st stage of 2-stage processing)
src2doc:
	for f in $(SRC_TOP_SCRIPTS); do \
          mkdir -p `dirname $(BUILD_DIR)/doxysrc/$$f`; \
	  $(SRC2DOC) -rename $(JS_SRC_DIR)/$$f > $(BUILD_DIR)/doxysrc/`dirname $$f`/`basename $$f .js`$(DOC_SUFFIX); \
	done

# run doxygen on whatever is in $(BUILD_DIR)/doxysrc (2nd stage)
apidoc_build: 
	@mkdir -p $(APIDOC_DIR)
	$(DOXYGEN_ENV_BUILD) $(DOXYGEN) $(DOXYGEN_CONFIG)

# to confirm that each produces either a class or a namespace
# exceptions are: dom/fix_dom.js burst_first.js burst_last.js
checkdoxy:
	@for f in $(SRC_TOP_SCRIPTS); do \
	  echo "==== file " $$f; \
          ls build/apidoc/html/*`basename $$f .js`* |grep -v png |grep -v members; \
	done

