####
# the public web site, except for api doc.
# targets: copydoc, tooldoc, sitedoc
####

####
# target "copydoc" (docsrc copying and filtering)
####

# docsrc/*.txt docsrc/*.png
SITE_COPY_FILES    := $(patsubst $(DOCSRC_DIR)/%,$(SITEDOC_DIR)/%,$(shell ls $(DOCSRC_DIR)/*.html $(DOCSRC_DIR)/*.gif $(DOCSRC_DIR)/*.css | grep -v intro.html))

copydoc: $(SITE_COPY_FILES) $(SITEDOC_DIR)/intro.html copydemos

echosite:
	echo $(SITE_COPY_FILES)

$(SITE_COPY_FILES): $(SITEDOC_DIR)/%: $(DOCSRC_DIR)/%
	@mkdir -p $(dir $@)
	$(CP) $< $@

$(SITEDOC_DIR)/intro.html: 
	@mkdir -p $(dir $@)
	$(CP) $(DOCSRC_DIR)/intro.html $@
	perl -p -i~ -e s/BURSTVERSION/$(BURSTVERSION)/g $@
	perl -p -i~ -e s/BUILDDATE/$(NOW)/g $@

####
# target "copydemos"
####
DEMO_FILES := $(patsubst $(DEMOS_DIR)/%,$(BUILD_DIR)/demos/%,$(shell ls $(DEMOS_DIR)/*.html))

copydemos: $(DEMO_FILES)

$(DEMO_FILES): $(BUILD_DIR)/demos/% : $(DEMOS_DIR)/%
	@mkdir -p $(dir $@)
	@echo copying demo $< to $@
	$(CP) $< $@

####
# doc generation
####

#gendoc: version_html tooldoc sitedoc
gendoc: tooldoc sitedoc

# always run the target regardless of whether the file exists
version_html:
	@mkdir -p $(dir $(VERSION_HTML))
	echo Ver $(BURSTVERSION), $(NOW) > $(VERSION_HTML)

# TBD html templating, possibly just s/%%([^%]|%[^%])*%%/$1/eg;

SITE_POD_FILES := $(patsubst $(DOCSRC_DIR)/%.pod,$(SITEDOC_DIR)/%.html,$(shell ls $(DOCSRC_DIR)/*.pod))

sitedoc: $(SITE_POD_FILES)

$(SITE_POD_FILES): $(SITEDOC_DIR)/%.html: $(DOCSRC_DIR)/%.pod
	@mkdir -p $(dir $@)
	$(POD2HTML)
	@rm pod2htm*

TOOL_PERL_SRC_FILES  := $(shell find $(TOOLS_DIR) -name '*.pl')
TOOL_JS_SRC_FILES    := $(shell find $(TOOLS_DIR) -name '*.js')
#TOOL_PERL_SRC_FILES  := $(shell cd $(TOOLS_DIR); find . -name '*.pl')
#TOOL_JS_SRC_FILES    := $(shell cd $(TOOLS_DIR); find . -name '*.js')

# TOOL_PERL_FILES      := $(addprefix $(TOOLDOC_DIR)/,$(TOOL_PERL_SRC_FILES))
# TOOL_JS_FILES        := $(addprefix $(TOOLDOC_DIR)/,$(TOOL_JS_SRC_FILES))

TOOL_PERL_FILES      := $(patsubst $(TOOLS_DIR)/%.pl,$(TOOLDOC_DIR)/%.html,$(TOOL_PERL_SRC_FILES))
TOOL_JS_FILES      := $(patsubst $(TOOLS_DIR)/%.js,$(TOOLDOC_DIR)/%.html,$(TOOL_JS_SRC_FILES))

tooldoc: $(TOOL_PERL_FILES) $(TOOL_JS_FILES)

$(TOOL_PERL_FILES): $(TOOLDOC_DIR)/%.html: $(TOOLS_DIR)/%.pl
	@echo making $@ from $< 
	@mkdir -p $(dir $@)
	$(POD2HTML)
	@rm pod2htm*

$(TOOL_JS_FILES): $(TOOLDOC_DIR)/%.html: $(TOOLS_DIR)/%.js
	@echo making $@ from $< 
	@mkdir -p $(dir $@)
	PROJECT_NAME=$(basename $@) OUTPUT_DIRECTORY=$(shell dirname $@) INPUT=$< INPUT_FILTER="$(SRC2DOC)" HTML_OUTPUT=. $(DOXYGEN) $(TOOLS_JSFILTER_DIR)/Doxyfile_single.txt

