/**
* @file fix_dom.js
*
* Utility file - attempts to bring up the builtin DOM objects to DOM compliance.
* This does not provide any additional functionality; for that see other files.
*
* Note that some libraries take the approach of extending the builtin DOM objects 
* of non-IE browsers to have non-standard IE methods like insertAdjacentHTML or innerHTML.
* We don't do that. Instead, such utilities are in burst.xml.DomUtil, not attached to builtin objects.
*
* <h3>Internet Explorer</h3>
* It is unfortunately difficult to do much about Internet Explorer.
* In IE, the DOM inheritance hierarchy (Object/Node/Element/HTMLElement) is not available.
* There is no HTMLElement, let alone HTMLElement.prototype. All DOM objects are just Object.
*
* That makes it rather hard to add or fix functions on those objects.
*
* Also, IE has no getter/setter ability like Moz does for adding variables from
* the "outside". Apparently JScript v7 ("JScript.Net") has setters and getters but
* that isn't in IE6, and just works for extending properties and not methods.
*
* An IE "behavior" with an onpropertychange might be used to add a custom property, though
* not a method.
*
* One workaround of having only Object instances available, would be to iterate through all
* nodes in the current document and add methods to those instances.
* See discussion at
* http://groups.google.com/groups?selm=3D610C83.2AAFCF67%40agricoreunited.com
* But apparently that doesn't work on text nodes (nodeType 3), and it seems like a lot of overhead.
* It also doesn't solve the problem of dynamically added nodes.
*
* So right now, the only thing we fix for IE is the lack of Node constants like ELEMENT_NODE.
*
*
* <h3>Mozilla</h3>
*
* In Moz, it is possible to extend the DOM objects, for example to add an implementation
* of createNodeIterator method.
* (Note that apparently at least NS6.1 PR1 did not have HTMLElement.prototype).
*
* Moz also has the setter/getter mechanism for adding attributes.
*
* Right now, we aren't doing anything for Moz.
*
* @author Copyright 2003 Mark D. Anderson (mda@discerning.com)
* @author Licensed under the Academic Free License 1.2 http://www.opensource.org/licenses/academic.php
*/

// nothing to do in this file if no window object
if (typeof window != 'undefined') {

if (!window.Node) {
  window.Node = {
    ELEMENT_NODE           : 1,
    ATTRIBUTE_NODE         : 2,
    TEXT_NODE              : 3,
    CDATA_SECTION_NODE     : 4,
    ENTITY_REFERENCE_NODE  : 5,
    ENTITY_NODE            : 6,
    PROCESSING_INSTRUCTION_NODE    : 7,
    COMMENT_NODE           : 8,
    DOCUMENT_NODE          : 9,
    DOCUMENT_TYPE_NODE     : 10,
    DOCUMENT_FRAGMENT_NODE : 11,
    NOTATION_NODE          : 12
  }
}

} // if (this.window) ...


bu_loaded('burst.xml.fix_dom');
